package Task::Sub::Spec;

our $VERSION = '0.02'; # VERSION

# todo: Sub::Spec::Exporter

1;
# ABSTRACT: Install all Sub::Spec modules


=pod

=head1 NAME

Task::Sub::Spec - Install all Sub::Spec modules

=head1 VERSION

version 0.02

=head1 DESCRIPTION

This task will install all Sub::Spec modules.

=head1 TASK CONTENTS

=head2 Included modules

=head3 L<Sub::Spec>

=head3 L<Sub::Spec::BashComplete>

=head3 L<Sub::Spec::CmdLine>

=head3 L<Sub::Spec::Examples>

=head3 L<Sub::Spec::Gen::ReadTable>

=head3 L<Sub::Spec::GetArgs::Argv>

=head3 L<Sub::Spec::GetArgs::Array>

=head3 L<Sub::Spec::GetArgs::GetPost>

=head3 L<Sub::Spec::HTTP>

=head3 L<Sub::Spec::HTTP::Server>

=head3 L<Sub::Spec::Object>

=head3 L<Sub::Spec::Response::Format>

=head3 L<Sub::Spec::Runner>

=head3 L<Sub::Spec::To::HTML>

=head3 L<Sub::Spec::To::Org>

=head3 L<Sub::Spec::To::Pod>

=head3 L<Sub::Spec::To::Text>

=head3 L<Sub::Spec::URI>

=head3 L<Sub::Spec::URI::http>

=head3 L<Sub::Spec::Use>

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__END__

